pub struct AvailabilityRequest {
pub emails: Vec<String>,
pub duration_minutes: u32,
pub interval_minutes: Option<u32>,
pub start_time: i64,
pub end_time: i64,
}Expand description
Request for querying availability/free-busy information.
Example
let request = AvailabilityRequest::builder()
.email("user@example.com")
.duration_minutes(30)
.start_time(1234567890)
.end_time(1234654290)
.build();Fields
emails: Vec<String>List of email addresses to check availability for.
duration_minutes: u32Duration of requested availability slots in minutes.
interval_minutes: Option<u32>Optional interval between availability slots in minutes. If not specified, defaults to the duration.
start_time: i64Unix timestamp indicating the start of the time range to check.
end_time: i64Unix timestamp indicating the end of the time range to check.
Implementations