pub struct AvailabilityResponse {
pub time_slots: Vec<TimeSlot>,
}Expand description
Response from the availability endpoint containing available time slots.
Example
let response = AvailabilityResponse {
time_slots: vec![
TimeSlot::new(
vec!["user@example.com".to_string()],
1234567890,
1234571490,
),
],
};Fields
time_slots: Vec<TimeSlot>List of available time slots for the queried participants.
Implementations