AvailabilityRequest

Struct AvailabilityRequest 

pub struct AvailabilityRequest {
    pub emails: Vec<String>,
    pub duration_minutes: u32,
    pub interval_minutes: Option<u32>,
    pub start_time: i64,
    pub end_time: i64,
}
Request for querying availability/free-busy information.

Example

let request = AvailabilityRequest::builder()
    .email("user@example.com")
    .duration_minutes(30)
    .start_time(1234567890)
    .end_time(1234654290)
    .build();

Fields

emails: Vec<String>

List of email addresses to check availability for.

duration_minutes: u32

Duration of requested availability slots in minutes.

interval_minutes: Option<u32>

Optional interval between availability slots in minutes. If not specified, defaults to the duration.

start_time: i64

Unix timestamp indicating the start of the time range to check.

end_time: i64

Unix timestamp indicating the end of the time range to check.

Implementations

Source

impl AvailabilityRequest

pub fn builder() -> AvailabilityRequestBuilder

Create a builder for constructing an AvailabilityRequest.

pub fn new( emails: Vec<String>, duration_minutes: u32, start_time: i64, end_time: i64, ) -> Self

Create a new availability request with required fields.